#
# spec file for package qsynth
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qsynth
Version:        0.9.12
Release:        1.1
Summary:        Graphical User Interface for fluidsynth
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://qsynth.sourceforge.net/qsynth-index.html
Source:         https://sourceforge.net/projects/qsynth/files/qsynth/%{version}/qsynth-%{version}.tar.gz
Patch1:         qsynth-fix_desktop_file.patch
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(fluidsynth) >= 2.0.0

%description
Qsynth is a fluidsynth GUI front-end application written in C++ around the Qt5
toolkit using Qt Designer.

%lang_package

%prep
%autosetup -p1

%build
%cmake_qt6
%qt6_build

%install
%qt6_install
%suse_update_desktop_file -r "org.rncbc.%{name}" AudioVideo Midi
%find_lang %{name} --with-qt

%files
%doc ChangeLog
%license LICENSE
%{_bindir}/qsynth
%{_datadir}/applications/org.rncbc.%{name}.desktop
%{_datadir}/icons/*/*/apps/org.rncbc.qsynth.png
%{_datadir}/icons/hicolor/scalable/apps/org.rncbc.qsynth.svg
%{_datadir}/metainfo
%{_datadir}/qsynth
%exclude %{_datadir}/qsynth/translations
%{_mandir}/man1/qsynth.1%{ext_man}
%{_mandir}/fr/man1/qsynth.1%{ext_man}

%files lang -f %{name}.lang
%{_datadir}/qsynth/translations

%changelog
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.12:
  * Restore all MIDI channels synth-engine funcionality, when the
    output peak-meters aren't opted in.
  * Preppings to next development cycle (Qt >= 6.6)
  * Optimized audio output peak-meters.
* Thu Apr  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.9.10
  * Bumping copyright headers to the brand new year.
- Use the rpm macros provided by the Qt6 packages
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.9:
  * Just bumping into the next develop cycle/season.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.8:
  * Add current system user-name to the singleton/unique application
    instance identifier.
* Sat Jun 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.7:
  * Main application icon is now presented in scalable format (SVG).
* Sat Feb 12 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.6
  * Migrated command line parsing to QCommandLineParser/Option
    (Qt >= 5.2)
  * New option to change the UI language translation.
  * Added DLS file type to the soundfonts selection dialog.
  * Fixed translations path to be relative to application
    runtime.
- Refresh qsynth-fix_desktop_file.patch
* Sun Jan  9 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.5
  * Dropped autotools (autoconf, automake, etc.) build system.
  * Fixed for Qt6 plugins path eg. widget theme or styles.
- Switch build to Qt6
- Refresh qsynth-fix_desktop_file.patch
* Sun Jul  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.4
  * All builds default to Qt6 (Qt >= 6.1) where available.
  * CMake is now the new official build system.
* Tue May 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.3
  * New Setup/Audio/WASAPI Exclusive Mode option added.
  * New Setup/MIDI/Auto Connect MIDI inputs option added.
  * Fix deprecated Reverb/Chorus API (FluidSynth >= 2.2.0).
  * All packaging builds switching to CMake.
* Mon Mar 15 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.2
  * Possible fix to the even number of audio channels not playing
    back through JACK when audio group number is set to 2.
* Sun Feb  7 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  * Fixed MIDI player to files that are drag and dropped
    after a first time following engine re-initialization.
  * Fix multi-channel support with JACK.
  * Early preparations for the New Year develop(ment) cycle.
- Drop qsynth-0.9.0_Qt512.patch (merged upstream)
* Thu Dec 17 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.0
  * Early fixing to build for Qt >= 6.0.0 and comply with C++17
    standard.
- Add qsynth-0.9.0_Qt512.patch
* Fri Jul 31 2020 aloisio@gmx.com
- Update to version 0.6.3
  * Left-clicking on the system-tray icon now simply
    toggles the main widget visibility, disregarding
    if already hidden undercover to other windows.
  * Early fixing to build for Qt >= 5.15.0.
* Tue Mar 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.2
  * A scalable (.svg) icon version has been added.
  * Make man page compression reproducible (after request
    by Jelle van der Waa, while on the Vee-Ones, thanks).
  * Ditching deprecated QTime methods for QElapsedTimer's
    (in compliance to Qt >= 5.14.0).
  * Bumped copyright headers into the New Year (2020).
* Mon Dec 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.1
  * Custom color (palette) theme editor introduced; color
    (palette) theme changes are now effective immediately,
    except on default.
  * Second attempt to fix the yet non-official though
    CMake build configuration.
  * When using autotools and ./configure --with-qt=...,
    it is also necessary to adjust the PKG_CONFIG_PATH
    environment variable (after a merge request by plcl
    aka. Pedro López-Cabanillas, while on qmidinet,
    thanks).
- Switch build to cmake
* Thu Oct 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.0
  * Updated the old yet non-oficial CMake build option.
  * Fix HiDPI display screen effective support (Qt >= 5.6).
  * System-tray icon context menu has been refactored to
    be exactly the same as the main-window context menu
    that is re-instantiated on demand.
  * Make sure compiler flags comply to c++11 as standard.
* Fri Jul 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.7
  * Updated for the newer Qt5 development tools (>= 5.13).
  * Configure updated to check for qtchooser availability.
  * Updated icon files into 128x128 base resolution.
* Thu Apr 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.6
  * Re-defined all main application UNIX signal handling.
* Mon Mar 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.5 (Pre-LAC2019 Release Frenzy)
  * Refactored all singleton/unique application instance
    setup logic away from X11/Xcb hackery.
  * HiDPI display screen support (Qt >= 5.6).
  * Bumped copyright headers into the New Year (2019).
* Wed Dec  5 2018 aloisio@gmx.com
- Update to version 0.5.4
  * Reset button now also resets master Gain, Reverb and
    Chorus to their "factory default" values.
  * Fixed Reverb and Chorus effects processing when audio
    output peak-meters are enabled on FluidSynth API V2.
  * Old deprecated Qt4 build support is no more.
  * System tray options now subject to current desktop
    environment availability.
* Wed Oct 10 2018 aloisio@gmx.com
- Update to version 0.5.3
  * Current FluidSynth version information added to command
    line output (-V, --version).
  * Overhaul adaptations to the FluidSynth API V2 (>= 2.0.0).
  * AppStream metadata updated to be the most compliant with
    latest freedesktop.org specification and recommendation.
- Dropped fluidsynthv2_overhaul.patch, fluidsynthv2_cmake.patch,
  fluidsynthv2_more.patch, fluidsynthv2_copyright.patch,
  fluidsynthv2_last.patch and fluidsynthv2_version.patch (merged
  upstream)
* Thu Sep 27 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.2
  * AppData/AppStream metadata is now settled under an all
    permisssive license (FSFAP).
  version 0.5.1
  * Disable singleton/unique application instance setup logic
    when the display server platform is not X11.
  * Fixed deprecated calls to fluid_synth_get_channel_info(),
    fluid_synth_set_midi_router() and fluid_settings_getstr()
    (as signaled on libfluidsynth >= 1.1.9).
  * A little hardening on the configure (autoconf) macro side.
- Backported fluidsynthv2_overhaul.patch, fluidsynthv2_cmake.patch,
  fluidsynthv2_more.patch, fluidsynthv2_copyright.patch,
  fluidsynthv2_last.patch and fluidsynthv2_version.patch to
  support fluidsynth 2.0.0
* Tue Feb 20 2018 jengelh@inai.de
- Remove unrealized future visions from description.
* Tue Feb 20 2018 aloisio@gmx.com
- Update to version 0.5.0
  * Added *.SF3 to soundfont files filter on Setup > Soundfonts
    > Open... file dialog.
  * Increased Soundfont bank-offset limit to 16384 (was 128).
  * Desktop entry specification file is now finally independent
    from build/configure template chains.
  * Updated target path for freedesktop.org's AppStream metainfo
    file (formerly AppData).
  version 0.4.4
  * Added French man page (by Olivier Humbert, thanks).
  * Make builds reproducible byte for byte, by getting rid of
    the configure build date and time stamps.
  version 0.4.3
  * Fixed a potential crash on the singleton/unique application
    instance setup.
  * Almost complete overhaul on the configure script command
    line options, wrt. installation directories specification,
    eg. --prefix, --bindir, --libdir, --datadir and --mandir.
  * Late French (fr) translation update (by Olivier Humbert,
    thanks).
  version 0.4.2
  * Old "Start minimized to system tray" option returns to setup.
  * Dropped the --enable-qt5 from configure as found redundant
    given that's the build default anyway (suggestion by Guido
    Scholz, while for Qtractor, thanks).
  version 0.4.1
  * Dropped old "Start minimized to system tray" option from setup.
  * CMake script lists update (patch by Orcan Ogetbil, thanks).
  * Added application keywords to freedesktop.org's AppData.
  * System-tray icon context menu has been fixed/hacked to show up
    again on Plasma 5 (aka. KDE5) notifications status area.
  * Prevent x11extras module from use on non-X11/Unix plaforms.
  * Messages standard output capture has been improved in both ways
    a non-blocking pipe may get.
  * Regression fix for invalid system-tray icon dimensions reported
    by some desktop environment frameworks.
  version 0.4.0
  * Desktop environment session shutdown/logout management has been
    also adapted to Qt5 framework.
  * Single/unique application instance control adapted to Qt5/X11.
  * Output meter scale text color fixed on dark color schemes.
  * Prefer Qt5 over Qt4 by default with configure script.
  * Complete rewrite of Qt4 vs. Qt5 configure builds.
  * A new top-level widget window geometry state save and restore
    sub-routine is now in effect.
  * Fixed for some strict tests for Qt4 vs. Qt5 configure builds.
  * German (de) translation update (by Guido Scholz, thanks).
  version 0.3.9
  * Added application description as freedesktop.org's AppData.
  * New user preference option on whether to show the nagging
    'program will keep running in the system tray' message, on
    main window close.
  * Application close confirm warning is now raising the main
    window as visible and active for due top level display,
    especially applicable when minimized to the system tray.
  * A man page has been added.
  * Translations install directory change.
  * Allow the build system to include an user specified LDFLAGS.
  * Czech (cs) translation updated (by Pavel Fric, thanks).
- Refreshed qsynth-fix_desktop_file.patch
- Dropped qsynth-remove_build_timestamps.patch (no longer
  necessary)
- Switched to Qt5 build
- Split locale files into separate -lang subpackage
- Spec cleanup
* Sat Jan  4 2014 pascal.bleser@opensuse.org
- update to 0.3.8:
  * Serbian (sr) translation added
- changes from 0.3.7:
  * new French (fr) translation
  * reversed (mouse) scroll-wheel effect on dial knob widgets
  * MIDI bank select mode control added to engine setup dialog
  * main window is now brought to front and (re)activated when clicking on the
    system tray icon instead of just hiding it
* Thu Jan  5 2012 pascal.bleser@opensuse.org
- initial version (0.3.6)
